@@ -153,7 +153,7 @@ void VcsAnnotationItemDelegate::renderBackground(QPainter* painter,
         const auto background = (normalStyle->hasProperty(QTextFormat::BackgroundBrush)) ? normalStyle->background().color() : QColor(Qt::white);
         const int background_y = background.red()*0.299 + 0.587*background.green()
                                                         + 0.114*background.blue();
-        // get random, but reproducable 8-bit values from last two bytes of the revision hash
+        // get random, but reproducible 8-bit values from last two bytes of the revision hash
         const uint revisionHash = qHash(revision);
         const int u = static_cast<int>((0xFF & revisionHash));
         const int v = static_cast<int>((0xFF00 & revisionHash) >> 8);
@@ -373,3 +373,5 @@ int VcsAnnotationItemDelegate::widthHintFromViewWidth(int viewWidth) const
 {
     return viewWidth * m_maxWidthViewPercent / 100;
 }
+
+#include "moc_vcsannotationitemdelegate.cpp"
