@@ -1,34 +1,14 @@
 /*
- * This file is part of KDevelop
- *
- * Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
- * Copyright 2015 Sergey Kalinichev <kalinichev.so.0@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2009 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2015 Sergey Kalinichev <kalinichev.so.0@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "sourcemanipulation.h"
 
-#include <QMimeDatabase>
-
 #include <interfaces/icore.h>
 #include <interfaces/isourceformattercontroller.h>
-#include <interfaces/isourceformatter.h>
 
 #include <language/codegen/coderepresentation.h>
 
@@ -249,12 +229,9 @@ bool SourceCodeInsertion::insertFunctionDeclaration(KDevelop::Declaration* decla
     int line = findInsertionPoint();
 
     decl = QLatin1String("\n\n") + applySubScope(decl);
-    const auto url = declaration->url().toUrl();
-    QMimeDatabase db;
-    QMimeType mime = db.mimeTypeForUrl(url);
-    auto i = ICore::self()->sourceFormatterController()->formatterForUrl(url, mime);
-    if (i) {
-        decl = i->formatSource(decl, url, mime);
+    const auto formatter = ICore::self()->sourceFormatterController()->fileFormatter(declaration->url().toUrl());
+    if (formatter) {
+        decl = formatter->format(decl);
     }
 
     return m_changeSet.addChange(DocumentChange(m_context->url(), insertionRange(line), QString(), decl));
