@@ -313,10 +313,15 @@ QVector<SourceFormatterStyle> CustomScriptPlugin::predefinedStyles() const
     return styles;
 }
 
-KDevelop::SettingsWidget* CustomScriptPlugin::editStyleWidget(const QMimeType& mime) const
+bool CustomScriptPlugin::hasEditStyleWidget() const
+{
+    return true;
+}
+
+SettingsWidgetPtr CustomScriptPlugin::editStyleWidget(const QMimeType& mime) const
 {
     Q_UNUSED(mime);
-    return new CustomScriptPreferences();
+    return SettingsWidgetPtr{new CustomScriptPreferences()};
 }
 
 static QString defaultSample()
@@ -513,8 +518,7 @@ CustomScriptPlugin::Indentation CustomScriptPlugin::indentation(const SourceForm
 void CustomScriptPreferences::updateTimeout()
 {
     const QString& text = indentPluginSingleton.data()->previewText(m_style, QMimeType());
-    QString formatted = indentPluginSingleton.data()->formatSourceWithStyle(m_style, text, QUrl(), QMimeType());
-    emit previewTextChanged(formatted);
+    emit previewTextChanged(text);
 }
 
 CustomScriptPreferences::CustomScriptPreferences()
@@ -567,7 +571,7 @@ void CustomScriptPreferences::load(const KDevelop::SourceFormatterStyle& style)
     updateTimeout();
 }
 
-QString CustomScriptPreferences::save()
+QString CustomScriptPreferences::save() const
 {
     return m_commandEdit->text();
 }
